@@ -15,14 +15,16 @@ def reindex(es, doc_class, index, options):
     """
 
     def get_actions():
-        for doc in doc_class.documents(cursor=options['cursor']):
+        for doc in doc_class.documents():
             action = {
                 '_index': index,
             }
             action.update(doc)
             yield action
 
-    actions = get_actions() if options['quiet'] else progress(get_actions(), count=doc_class.count(), label=doc_class.__name__)
+    actions = (
+        get_actions() if options['quiet'] else progress(get_actions(), count=doc_class.count(), label=f"{doc_class.__name__} ({index})")
+    )
     bulk(es, actions)
     es.indices.refresh(index=index)
 
@@ -66,12 +68,6 @@ class Command(BaseCommand):
                             default=True,
                             help='Only create the mappings, do not index any data',
         )
-        parser.add_argument('--cursor',
-                            action='store_true',
-                            dest='cursor',
-                            default=False,
-                            help='Use a server-side cursor when fetching data for indexing',
-        )
         parser.add_argument('args', nargs=argparse.REMAINDER)
 
     def handle(self, *args, **options):
